@@ -44,7 +44,7 @@ int main (int argc, char const *const *argv, char const *const *envp)
   int flagpath = 0, flagcleanup = 0, flagopt = 0, flagpos = 0 ;
   PROG = "emptyenv" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "pcoP", &l) ;
