@@ -18,7 +18,7 @@ int main (int argc, char const *const *argv)
   stralloc sa = STRALLOC_ZERO ;
   PROG = "getcwd" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "Ee", &l) ;
