@@ -19,7 +19,7 @@ int main (int argc, char const *const *argv)
   int df = 0 ;
   PROG = "heredoc" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "d", &l) ;
