@@ -19,7 +19,7 @@ int main (int argc, char const **argv, char const *const *envp)
   pid_t pid ;
   PROG = "ifelse" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "nX", &l) ;
