@@ -20,7 +20,7 @@ int main (int argc, char const *const *argv)
   int changemode = 0 ;
   PROG = "redirfd" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "rwuaxnb", &l) ;
