@@ -21,7 +21,7 @@ int main (int argc, char const *const *argv)
   unsigned int i = 0 ;
   PROG = "shift" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "n:b:", &l) ;
