@@ -12,7 +12,7 @@
 int exlsn_importas (int argc, char const **argv, char const *const *envp, exlsn_t *info)
 {
   eltransforminfo_t si = ELTRANSFORMINFO_ZERO ;
-  subgetopt_t localopt = SUBGETOPT_ZERO ;
+  subgetopt localopt = SUBGETOPT_ZERO ;
   elsubst_t blah ;
   char const *defaultval = 0 ;
   char const *x ;
